ItemController class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
isAttached
→ bool
Whether any ScrollablePositionedList objects are attached this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
jumpTo ({required int index , double alignment = 0 })
→ void
Immediately, without animation, reconfigure the list so that the item at
index's leading edge is at the given alignment.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scrollTo ({required int index , double alignment = 0 , required Duration duration , Curve curve = Curves.linear , List <double > opacityAnimationWeights = const [40, 20, 40] })
→ Future <void >
Animate the list over duration using the given curve such that the
item at index ends up with its leading edge at the given alignment.
See jumpTo for an explanation of alignment.
inherited
toString ()
→ String
A string representation of this object.
inherited
horizontal_menu_to_vertical_sections 1.1.1